Equalize
========

Usage: equalize()

Description
-----------

This filter equalizes the color distribution in the image.

Arguments
---------

No arguments.

Example
-------

.. image:: images/tom_before_brightness.jpg
    :alt: Picture before the equalize filter

`<http://thumbor-server/filters:equalize()/some/image.jpg>`_

.. image:: images/tom_after_equalize.jpg
    :alt: Picture after the equalize filter
